@@ -70,8 +70,8 @@ def bCritical(msg, *args, **kwargs):
     logging.getLogger(_loggerName).critical(msg, *args, **kwargs)
 
 
-def bGetPath(basePath, extendPath):
-    return os.path.abspath(os.path.join(basePath, extendPath))
+def bGetPath(basePath, *parList):
+    return os.path.abspath(os.path.join(basePath, *parList))
 
 
 def bWriteFile(file, data, encoding='utf8', newline='\n'):
